@@ -11,7 +11,7 @@ use Text::Hunspell;
 use Test::Text::Sentence qw(split_sentences);
 use v5.22;
 
-use version; our $VERSION = qv('0.6.5'); # Works with UTF8 and includes Text::Sentence
+use version; our $VERSION = qv('0.6.6'); # Really works with RMarkdown
 
 use parent 'Test::Builder::Module'; # Included in Test::Simple
 
@@ -69,7 +69,7 @@ sub check {
   my @sentences;
   for my $f ( @{$self->files}) {
     my $file_content= path($f)->slurp_utf8;
-    if ( $f =~ /(\.md|\.markdown)/ ) {
+    if ( $f =~ /(\.md|\.markdown|\.Rmd|\.Rmarkdown)/ ) {
       $file_content = _strip_urls( $file_content);
       $file_content = _strip_code( $file_content);
     }
@@ -95,8 +95,9 @@ sub _strip_urls {
 
 sub _strip_code {
   my $text = shift || carp "No text in _strip_code";
+  $text =~ s/---[\w\W]*?---//g;
   $text =~ s/~~~[\w\W]*?~~~//g;
-  $text =~ s/```[\w\W]+?```//g;
+  $text =~ s/```.+?```//g;
   $text =~ s/`[^`]+?`//g;
   return $text;
 }
@@ -126,7 +127,7 @@ __END__
 
 =head1 NAME
 
-Test::Text - A module for testing text files for spelling and (maybe) more. 
+Test::Text - A module for testing text files for spelling and (maybe) more.
 
 =head1 VERSION
 
@@ -136,8 +137,9 @@ This document describes Test::Text version 0.5.0
 
     use Test::Text;
 
-    my $dir = "path/to/text_dir"; 
-    my $data = "path/to/data_dir"; 
+    # This directory will include .md, .Rmd, and text files
+    my $dir = "path/to/text_dir";
+    my $data = "path/to/data_dir";
 
     my $tesxt = Test::Text->new($text_dir, $dict_dir); # Defaults to English: en_US and all files
 
